==> mirza_pro-3.2-Stable.zip: mirza_pro-3.2-Stable/README.md <==
## ⭐ لطفاً پروژه را **Star** کنید تا دیگران هم آن را پیدا کنند!


---

 #### **💸  حمایت مالی**


<details>
  <summary> دونیت </summary>

👉 [حمایت از دولوپر میرزا NowPayments](https://nowpayments.io/donation/permiumbotmirza)



  

</details>

---

#### **🌐 آموزش نصب هاست ( سیپنل اشتراکی )**  

<details>
  <summary> آموزش مهاجرت </summary>


### راهنمای مهاجرت از نسخه رایگان به نسخه پرو



#### 1️⃣ ابتدا سورس نسخه رایگان را حذف کنید، ولی قبل از آن، فایل config.php را باز کرده و اطلاعات مهم مثل دیتابیس، آیدی عددی و توکن ربات را کپی کنید.
#### 2️⃣ سپس سورس نسخه پرو را دانلود و استخراج کنید.
#### 3️⃣ مسیر زیر را در مرورگر باز کنید (به جای domin.ir و botmirzapanel، دامنه و مسیر استخراج شده‌ی خودتان را وارد کنید):

```
https://domin.ir/botmirzapanel/installer
```

#### 4️⃣ اطلاعات لازم که در مرحله قبل از config.php کپی کرده‌اید را وارد کنید.
#### 5️⃣ در صورتی که قصد نصب اولیه دارید، گزینه «نصب ساده» را انتخاب کنید.
#### 6️⃣ اگر می‌خواهید به‌صورت رایگان از نسخه فعلی خود به نسخه Pro مهاجرت کنید، گزینه «مهاجرت به نسخه Pro» را انتخاب نمایید.

</details>

---




#### **🔄  آموزش آپدیت سورس هاست سیپنل / aapanel**


<details>
  <summary> توضیحات </summary>



#### 1️⃣ ابتدا سورس نسخه‌ی قبلی را به‌طور کامل حذف کنید. پیش از پاک‌سازی، محتوای فایل config.php را به‌طور کامل کپی و ذخیره نمایید.
#### 2️⃣ سورس نسخه‌ی جدید را دانلود کرده و در هاست (cPanel یا aaPanel) آپلود کنید.
#### 3️⃣ پس از آپلود، حتماً پوشه‌ی installer را حذف کنید.
#### 4️⃣ سپس فایل config.php را باز کرده، تمامی محتوای آن را پاک کنید و محتوای نسخه‌ی قبلی را در آن جایگزین نمایید.
#### 5️⃣ در صورتی که ربات پس از آپلود به‌درستی کار نکرد، یک‌بار آدرس زیر را در مرورگر اجرا کنید (به جای domin.ir و botmirzapanel، دامنه و مسیر استخراج شده‌ی خودتان را وارد کنید)


```
https://domin.ir/botmirzapanel/index.php
```




</details>

---


#### **🛜  آموزش  اسکریپت سرور ( مهاجرت )**


<details>
  <summary> توضیحات </summary>

#### 1️⃣ ابتدا اسکریپت زیر را کپی کرده و بر روی سرور اجرا کنید.

```
bash -c "$(curl -L https://raw.githubusercontent.com/Mmd-Amir/mirza_pro/main/install.sh)"
```

#### 2️⃣ سپس گزینه‌ٔ «2» را انتخاب نمایید تا فرآیند به‌روزرسانی انجام شود.
#### 3️⃣ پس از آن، گزینه‌ٔ «10» را انتخاب کنید تا مجوزهای لازم اعمال شده و آدرس نصب‌کننده (Installer) در اختیار شما قرار گیرد.
#### 4️⃣ پس از دریافت آدرس وبی ارائه‌شده، وارد آن شوید، بخش « سرور » را انتخاب کنید و مراحل نصب را ادامه دهید.
</details>


---




#### **↩️  آموزش نصب اسکریپت سرور ( در صورتی که قبلا نصب نشده )**


<details>
  <summary> نصب سرور ساده  </summary>

  #### 1️⃣ ابتدا اسکریپت زیر را بر روی سرور اجرا کنید.
 ```
  bash -c "$(curl -L https://raw.githubusercontent.com/Mmd-Amir/mirza_pro/main/install.sh)"
```

#### 2️⃣ سپس گزینهٔ «1» را انتخاب کرده و اطلاعات مورد نیاز را مطابق درخواست وارد نمایید.
#### 3️⃣ گزینهٔ 10 را انتخاب کنید تا مجوزهای مربوط به فایل‌ها به‌صورت خودکار تنظیم شود.
#### 4️⃣ پس از اتمام کار، از اسکریپت خارج شوید و برای حذف فایل (Installer) دستور زیر را اجرا کنید:

```
rm -r /var/www/html/mirzabotconfig/installer
```

### ⛔️حذف فایل Installer الزامی است.
</details>

---


#### **🟩  آموزش نصب aapanel**


<details>
  <summary> مقدمات </summary>

  #### 1️⃣ ضروری است که وب‌سرور شما بر روی aaPanel با نسخه OpenLiteSpeed 1.8.4 اجرا شود.
  #### 2️⃣ سایر مراحل را مطابق با راهنمای «آموزش نصب روی هاست» ادامه دهید.

</details>


---



#### **📊  اطلاعات کلی**


<details>
  <summary> توضیحات </summary>


---

| php | کرون جاب | 
|--------|------|
| 8.3 / 8.4  | اجباری |

  
</details>

==> mirza_pro-3.8-Stable.zip: mirza_pro-3.8-Stable/README.md <==
## ⭐ لطفاً پروژه را **Star** کنید تا دیگران هم آن را پیدا کنند!


---

 #### **💸  حمایت مالی**


<details>
  <summary> دونیت </summary>

👉 [حمایت از دولوپر میرزا NowPayments](https://nowpayments.io/donation/permiumbotmirza)



  

</details>

---

#### **🌐 آموزش نصب هاست ( مهاجرت )**  

<details>
  <summary> آموزش مهاجرت </summary>


### راهنمای مهاجرت از نسخه رایگان به نسخه پرو



#### 1️⃣ ابتدا سورس نسخه رایگان را حذف کنید، ولی قبل از آن، فایل config.php را باز کرده و اطلاعات مهم مثل دیتابیس، آیدی عددی و توکن ربات را کپی کنید.
#### 2️⃣ سپس سورس نسخه پرو را دانلود و استخراج کنید.
#### 3️⃣ مسیر زیر را در مرورگر باز کنید (به جای domin.ir و botmirzapanel، دامنه و مسیر استخراج شده‌ی خودتان را وارد کنید):

```
https://domin.ir/botmirzapanel/installer
```

#### 4️⃣ اطلاعات لازم که در مرحله قبل از config.php کپی کرده‌اید را وارد کنید.
#### 5️⃣ در صورتی که قصد نصب اولیه دارید، گزینه «نصب ساده» را انتخاب کنید.
#### 6️⃣ اگر می‌خواهید به‌صورت رایگان از نسخه فعلی خود به نسخه Pro مهاجرت کنید، گزینه «مهاجرت به نسخه Pro» را انتخاب نمایید.

</details>

---



#### **🌐 آموزش نصب هاست ( نصب ساده)**  

<details>
  <summary> آموزش نصب ساده </summary>





#### 1️⃣ ابتدا اخرین نسخه را از مسیر زیر فایل zip را دانلود کنید سپس فایل ZIP را در هاست خود آپلود کرده و از حالت فشرده خارج نمایید.

```
https://github.com/Mmd-Amir/mirza_pro/releases
```

 #### 2️⃣مسیر زیر را در مرورگر باز کنید (به جای domin.ir و botmirzapanel، دامنه و مسیر استخراج شده‌ی خودتان را وارد کنید):

```
https://domin.ir/botmirzapanel/installer
```

#### 3️⃣ در صورتی که قصد نصب اولیه دارید، گزینه «نصب ساده» را انتخاب کنید.

</details>

---




#### **🔄  آموزش آپدیت سورس هاست سیپنل / aapanel**


<details>
  <summary> توضیحات </summary>



#### 1️⃣ ابتدا سورس نسخه‌ی قبلی را به‌طور کامل حذف کنید. پیش از پاک‌سازی، محتوای فایل config.php را به‌طور کامل کپی و ذخیره نمایید.
#### 2️⃣ سورس نسخه‌ی جدید را دانلود کرده و در هاست (cPanel یا aaPanel) آپلود کنید.
#### 3️⃣ پس از آپلود، حتماً پوشه‌ی installer را حذف کنید.
#### 4️⃣ سپس فایل config.php را باز کرده، تمامی محتوای آن را پاک کنید و محتوای نسخه‌ی قبلی را در آن جایگزین نمایید.
#### 5️⃣ در صورتی که ربات پس از آپلود به‌درستی کار نکرد، یک‌بار آدرس زیر را در مرورگر اجرا کنید (به جای domin.ir و botmirzapanel، دامنه و مسیر استخراج شده‌ی خودتان را وارد کنید)


```
https://domin.ir/botmirzapanel/index.php
```




</details>

---


#### **🛜  آموزش  اسکریپت سرور ( مهاجرت )**


<details>
  <summary> توضیحات </summary>

#### 1️⃣ ابتدا اسکریپت زیر را کپی کرده و بر روی سرور اجرا کنید.

```
bash -c "$(curl -L https://raw.githubusercontent.com/Mmd-Amir/mirza_pro/main/install.sh)"
```

#### 2️⃣ سپس گزینه‌ٔ «2» را انتخاب نمایید تا فرآیند به‌روزرسانی انجام شود.
#### 3️⃣ پس از آن، گزینه‌ٔ «10» را انتخاب کنید تا مجوزهای لازم اعمال شده و آدرس نصب‌کننده (Installer) در اختیار شما قرار گیرد.
#### 4️⃣ پس از دریافت آدرس وبی ارائه‌شده، وارد آن شوید، بخش « سرور » را انتخاب کنید و مراحل نصب را ادامه دهید.
</details>


---




#### **↩️  آموزش نصب اسکریپت سرور ( در صورتی که قبلا نصب نشده )**


<details>
  <summary> نصب سرور ساده  </summary>

  #### 1️⃣ ابتدا اسکریپت زیر را بر روی سرور اجرا کنید.
 ```
  bash -c "$(curl -L https://raw.githubusercontent.com/Mmd-Amir/mirza_pro/main/install.sh)"
```

#### 2️⃣ سپس گزینهٔ «1» را انتخاب کرده و اطلاعات مورد نیاز را مطابق درخواست وارد نمایید.
#### 3️⃣ گزینهٔ 10 را انتخاب کنید تا مجوزهای مربوط به فایل‌ها به‌صورت خودکار تنظیم شود.
#### 4️⃣ پس از اتمام کار، از اسکریپت خارج شوید و برای حذف فایل (Installer) دستور زیر را اجرا کنید:

```
rm -r /var/www/html/mirzabotconfig/installer
```

### ⛔️حذف فایل Installer الزامی است.
</details>

---


#### **🟩  آموزش نصب aapanel**


<details>
  <summary> مقدمات </summary>

  #### 1️⃣ ضروری است که وب‌سرور شما بر روی aaPanel با نسخه OpenLiteSpeed 1.8.4 اجرا شود.
  #### 2️⃣ سایر مراحل را مطابق با راهنمای «آموزش نصب روی هاست» ادامه دهید.

</details>


---



#### **📊  اطلاعات کلی**


<details>
  <summary> توضیحات </summary>


---

| php | کرون جاب | 
|--------|------|
| 8.3 / 8.4  | اجباری |

  
</details>
